---
title: 결제모듈
category: 서비스 종류 (결제대행사별 지원서비스) > 결제모듈 > 결제모듈
seo:
  title: 결제모듈
  description: >-
    포트원에서 제공하는 결제 모듈입니다. 결제 모듈별 지원하는 결제대행사 및 기능이 상이하므로 개발하고자 하는 결제대행사 및 기능에 따라
    버전을 선택하시어 연동하시길 바랍니다.
  keywords:
    - 결제모듈
    - V1
    - V2
tags:
  - 공통
pgCompanies:
  - 공통
searchTags:
  - ' 서비스 종류'
  - 결제모듈
  - 포트원결제모듈
  - 포트원모듈
  - V1
  - V2
  - 라이트닝
---

<Callout content="포트원에서 제공하는 결제 모듈입니다.
결제 모듈별 지원하는 결제대행사 및 기능이 상이하므로 개발하고자 하는 결제대행사 및 기능에 따라 버전을 선택하시어 연동하시길 바랍니다." />

## <Highlight text="포트원 결제 모듈 버전" />

### **결제모듈 V1**

- 결제 대행사 및 결제수단 연동 국내외 30개 PG사를 통한 최적의 결제수단 선택 가능
- 데이터 통합 관리 관리자콘솔을 통한 PG사 결제 데이터 확인 / 취소 / 환불 / 본인인증 / 현금영수증 관리

### **결제모듈 V2**

- 혁신적인 개발자 경험: 쉽고 편리한 결제 연동

<Indent level="1">

- Open API Spec Download
- 직관적인 스키마 설계
- npm, Typescript 지원

</Indent>

- 내부 시스템 개선: 풍부한 데이터와 견고한 서버
- 확장성: 무한한 가능성을 열어주는 결제 시스템
- 안정성: 신뢰할 수 있는 서버
- 완벽한 데이터 보존: 우수한 데이터 정합성과 풍부한 정보 제공
- 기능 확장: 신속한 업데이트와 혁신
- 사용 가능한 PG사

<Indent level="1">

- 결제 : 나이스페이먼츠, 토스페이먼츠, 이니시스, 스마트로, KSNET, 카카오페이, 네이버페이, 페이팔
- 본인인증 : 다날 (휴대폰 본인인증) , 이니시스(통합인증)

</Indent>
